remove static method

void remove(
  1. InputSystem system
)

Detaches the sources and guard installed on system, if any, so a later ensure installs fresh ones.

Implementation

static void remove(InputSystem system) {
  final installed = _installed[system];
  if (installed == null) return;
  _installed[system] = null;
  FocusManager.instance.removeListener(installed._updateTextEntry);
  system
    ..removeSource(installed.keyboard)
    ..removeSource(installed.mouse)
    ..removeSource(installed.gamepads);
}