A vector read from a stick control.
Constructors
-
StickBinding(GamepadControl control, {List<
Processor> processors = const []}) -
The vector of
control, a ControlKind.stick control.const
Properties
- control → GamepadControl
-
The stick read.
final
-
controls
→ Iterable<
Control> -
The controls whose values this binding reads, excluding gate modifiers.
These are what a firing binding consumes for lower contexts.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
-
parts
→ Map<
String, Control> -
The named parts a rebind can address individually (
up,down), or empty for a binding with a single control.no setterinherited -
processors
→ List<
Processor> -
Transforms applied to this binding's value, in order.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited